@@ -37,9 +37,7 @@ class Pages(models.Model):
         return self.slug
 
     def get_absolute_url(self):
-        current_site = Site.objects.get(id=conf.SITE_ID)
-        myurl = "http://"+current_site.domain
-        return myurl + reverse('app_flatpage-detail', kwargs={'slug': self.slug})
+        return reverse('app_flatpage-detail', kwargs={'slug': self.slug})
 
     def save(self, *args, **kwargs):
         datenow = int(time.time())
